@@ -2,7 +2,6 @@ import logging
 import os
 import platform
 import subprocess
-from enterprise import RemoteControlException
 
 
 class RemoteCommand:
@@ -31,8 +30,17 @@ class RemoteCommand:
             except FileNotFoundError as e:
                 logging.error(e)
                 return False
+
+        elif platform.system().lower() == 'windows':
+            try:
+                RemoteCommand._run_command(f'type {cmd}')
+                return True
+            except FileNotFoundError as e:
+                logging.error(e)
+                return False
         else:
-            logging.error('not running on linux, can\'t run cat')
+            logging.error(f'not running on linux or windows'
+                          f' can\'t run cat or type, current system is {platform.system()}')
             return False
 
     @staticmethod
